@@ -2,7 +2,7 @@
 sentry.utils.javascript
 ~~~~~~~~~~~~~~~~~~~~~~~
 
-:copyright: (c) 2010-2012 by the Sentry Team, see AUTHORS for more details.
+:copyright: (c) 2010-2013 by the Sentry Team, see AUTHORS for more details.
 :license: BSD, see LICENSE for more details.
 """
 from django.core.urlresolvers import reverse
@@ -12,6 +12,7 @@ from sentry.constants import STATUS_RESOLVED
 from sentry.models import Group, GroupBookmark
 from sentry.templatetags.sentry_plugins import get_tags
 from sentry.utils import json
+from sentry.utils.db import attach_foreignkey
 
 
 transformers = {}
@@ -62,6 +63,8 @@ class GroupTransformer(Transformer):
     def attach_metadata(self, objects, request=None):
         from sentry.templatetags.sentry_plugins import handle_before_events
 
+        attach_foreignkey(objects, Group.project, ['team'])
+
         if request and objects:
             handle_before_events(request, objects)
 
@@ -101,7 +104,7 @@ class GroupTransformer(Transformer):
             'lastSeen': obj.last_seen.isoformat(),
             'timeSpent': obj.avg_time_spent,
             'canResolve': request and request.user.is_authenticated(),
-            'isResolved': obj.status == STATUS_RESOLVED,
+            'isResolved': obj.get_status() == STATUS_RESOLVED,
             'isPublic': obj.is_public,
             'score': getattr(obj, 'sort_value', 0),
             'project': {
